@@ -36,7 +36,7 @@ filter..data.frame <- function(.df, ..., .by = NULL) {
 
   mask <- build_data_mask(dots)
 
-  dots <- prep_exprs(dots, .df)
+  dots <- prep_exprs(dots, .df, !!.by)
 
   i <- expr(Reduce('&', list(!!!dots)))
 
